@@ -1,4 +1,5 @@
 import logging as log
+import re
 
 import pytest
 from init_python_project.cli import app
@@ -15,3 +16,9 @@ def test_default_values(cli):
     result = cli("--help")
     log.debug(result.output)
     assert result.output.strip().startswith("Usage: init-python-project")
+
+
+def test_version(cli):
+    result = cli("--version")
+    log.debug(result.output)
+    assert re.match(r"^\d\.\d\.\d$", result.output.strip()), "should return semantic version number"
